import { createRouter, createWebHashHistory } from 'vue-router'
const routes = [
    {
        path: '/',
        redirect: '/login'
    },
    {
        path: '/login',
        name: 'login',
        meta: {
            title: '登录'
        },
        component: () => import('../view/Login.vue')
    },
    {
        path: '/home',
        name: '主页',
        meta: {
            title: '主页'
        },
        component: () => import('../view/Home.vue'),
        redirect: '/index',
        children: [
            {
                path: '/index',
                meta: {
                    title: '首页'
                },
                component: () => import('../view/Welcome.vue')
            },
            {
                path: '/user/list',
                meta: {
                    title: '资源管理'
                },
                component: () => import('../view/resource/Index.vue'),
            },
            {
                path: '/product/list',
                meta: {
                    title: '产品管理'
                },
                component: () => import('../view/product/product.vue'),
            },
            {
                path: '/product/detail',
                meta: {
                    title: '产品详情'
                },
                component: () => import('../view/product/Detail.vue'),
            },
            {
                path: '/product/add',
                meta: {
                    title: '添加产品'
                },
                component: () => import('../view/product/add.vue'),
            },
            {
                path: '/contents/list',
                meta: {
                    title: '招募和新闻管理'
                },
                component: () => import('../view/contents/contents.vue'),
            },
            {
                path: '/contents/detail',
                meta: {
                    title: '招募和新闻详情'
                },
                component: () => import('../view/contents/Detail.vue'),
            },
            {
                path: '/contents/add',
                meta: {
                    title: '添加招募和新闻详情'
                },
                component: () => import('../view/contents/add.vue'),
            },
            {
                path: '/serves/add',
                meta: {
                    title: '添加服务'
                },
                component: () => import('../view/serve/add.vue'),
            },
            {
                path: '/serves/detail',
                meta: {
                    title: '服务详情'
                },
                component: () => import('../view/serve/Detail.vue'),
            },
            {
                path: '/serves/list',
                meta: {
                    title: '服务管理'
                },
                component: () => import('../view/serve/serves.vue'),
            },
            {
                path: '/user/detail',
                meta: {
                    title: '用户详情'
                },
                component: () => import('../view/resource/Detail.vue'),
            },
        ]
    },
]
const router = createRouter({
    history: createWebHashHistory(),
    routes
})
// 挂载路由导航守卫：to表示将要访问的路径，from表示从哪里来，next是下一个要做的操作
router.beforeEach((to, from, next) => {
    // 修改页面 title
    if (to.meta.title) {
      document.title = '知否课堂后台管理系统 - ' + to.meta.title
    }
    // 放行登录页面
    if (to.path === '/login') {
      return next()
    }
    // 获取token
    // const token= sessionStorage.getItem('token')
    // if (!token) {
    //   return next('/login')
    // } else {
    //   next()
    // }
    return next()
  })
  
// 导出路由
export default router